# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from six import python_2_unicode_compatible
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel


@python_2_unicode_compatible
class Office(DateModel, UserModel, StatusModel, OrderedModel):
    """
    Store Office
    """
    code = models.CharField(
        primary_key=True,
        max_length=15,
        verbose_name=_("code")
    )
    name = models.CharField(
        unique=True,
        max_length=50,
        verbose_name=_("office")
    )
    description = models.TextField(
        blank=True,
        max_length=255,
        verbose_name=_("description")
    )
    phone = models.CharField(
        max_length=20,
        verbose_name=_("phone"),
    )
    fax = models.CharField(
        max_length=20,
        verbose_name=_("fax"),
    )
    email = models.EmailField(
        max_length=100,
        blank=True, null=True,
        verbose_name=_("email"),
    )

    class Meta:
        verbose_name = _("office")
        verbose_name_plural = _("offices")
        ordering = ("ordering", "name")
        permissions = (
            ("list_office", "Can list office"),
            ("detail_office", "Can detail office"),
            ("disable_office", "Can disable office"),
        )

    def __str__(self):
        return self.name
